#
# spec file for package python-jupyter-lsp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shortversion 2.2.4
Name:           python-jupyter-lsp
Version:        2.2.4
Release:        1.2
Summary:        LSP for Jupyter Notebook/Lab server
License:        BSD-3-Clause
# SourceRepository: https://github.com/jupyter-lsp/jupyterlab-lsp
URL:            https://github.com/jupyter-lsp/jupyterlab-lsp/tree/main/python_packages/jupyter_lsp
Source:         https://files.pythonhosted.org/packages/source/j/jupyter-lsp/jupyter-lsp-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module importlib_metadata >= 4.8.3 if %python-base < 3.10}
BuildRequires:  %{python_module jupyter_server >= 1.1.2}
# /SECTION
BuildRequires:  fdupes
Requires:       jupyter-lsp = %{version}
Requires:       python-jupyter_server >= 1.1.2
Requires:       (python-importlib_metadata >= 4.8.3 if python-base < 3.10)
Provides:       python-jupyter_lsp = %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
Multi-Language Server WebSocket proxy for Jupyter Notebook/Lab server

%package -n jupyter-lsp
Summary:        LSP for Jupyter Notebook/Lab server - Config
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(jupyter-lsp) = %{shortversion}
Suggests:       python3-jupyter-lsp

%description -n jupyter-lsp
Multi-Language Server WebSocket proxy for Jupyter Notebook/Lab server
Jupyter config

%prep
%autosetup -p1 -n jupyter-lsp-%{version}

%build
%pyproject_wheel
sed -e /cov/d -e /--flake8/d -i setup.cfg

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# no R language server
donttest="test_r_package_detection"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/jupyter_lsp
%{python_sitelib}/jupyter_lsp-%{version}.dist-info

%files -n jupyter-lsp
%doc README.md
%license LICENSE
%_jupyter_config %_jupyter_server_confdir/jupyter-lsp-jupyter-server.json

%changelog
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.2.4
  * fix websocket handler incorrectly inheriting from APIHandler
    rather than JupyterHandler (#1069)
  * remove unused notebook config entry point (#1069)
  * support latest version of typescript-language-server (#1064)
* Fri Jan 19 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.2.2
  * address warning about renamed extension_points (#1035)
  * fix compatibility with jupyter server 1.x
  * fix an authentication-related security vulnerability
    GHSA-4qhp-652w-c22x CVE-2024-22415 boo#1218976
  * add authorization support (lsp resource, jupyter-server v2+
    only) - this allows server operators for fine grained access
    control, e.g. in case if specific users (such as guest or
    read-only users) should not be allowed to access LSP; this is
    in addition to authentication fixes
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- udpate to 2.2.1:
  * use `APIHandler` over `JupyterHandler` to get CORS OPTIONS
  * use `shutil.which` to discover `npm` executable on Windows
  * resolve traitlets type warnings, lint, remove six #1015
  * use `sys.executable` in stdio tests #998
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Suggest primary python package -- boo#1214354
* Sun Jun 11 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v2.2.0
- Required by jupyterlab 4
